==> jc-1.4.0.tar.gz: soot/javaToJimple/jj/ExtensionInfo.h <==
// public class soot.javaToJimple.jj.ExtensionInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b87d6875b316a8f polyglot_ext_jl_ExtensionInfo
// @dep_class b1e2e9278240b294 polyglot_frontend_AbstractExtensionInfo
// @dep_class 155e6493c3c373f soot_javaToJimple_jj_ExtensionInfo

// header file dependencies
// @dep_header polyglot_ext_jl_ExtensionInfo

#include "polyglot/ext/jl/ExtensionInfo.h"

#ifndef _JC_soot_javaToJimple_jj_ExtensionInfo_H_
#define _JC_soot_javaToJimple_jj_ExtensionInfo_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_FileSource$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Parser$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_ErrorQueue$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs	_jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs	_jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$refs	_jc_soot_javaToJimple_jj_ExtensionInfo$refs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs	_jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$object	_jc_soot_javaToJimple_jj_ExtensionInfo$object;

typedef const struct _jc_soot_javaToJimple_jj_ExtensionInfo$vmethods	_jc_soot_javaToJimple_jj_ExtensionInfo$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtable	_jc_soot_javaToJimple_jj_ExtensionInfo$vtable;
typedef const struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtype	_jc_soot_javaToJimple_jj_ExtensionInfo$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_ExtensionInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$compilerName$20b6c9308360447c(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$createNodeFactory$4af76fcc0af28194(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$createTypeSystem$0b3473dcf2a9d954(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$defaultFileExtension$d54a311b3a2f1a9a(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$parser$41009ef32420079c(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_io_Reader$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$passes$def8d891d63f548c(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_polyglot_frontend_Job$object *);
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$sourceJobMap$320bdf7d2bd13eea(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
extern void _jc_soot_javaToJimple_jj_ExtensionInfo$method$sourceJobMap$d91400766cfa0821(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_util_HashMap$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$compilerName$20b6c9308360447c;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$createNodeFactory$4af76fcc0af28194;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$createTypeSystem$0b3473dcf2a9d954;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$defaultFileExtension$d54a311b3a2f1a9a;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$parser$41009ef32420079c;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$passes$def8d891d63f548c;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$sourceJobMap$320bdf7d2bd13eea;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$sourceJobMap$d91400766cfa0821;

// Static methods
extern void _jc_soot_javaToJimple_jj_ExtensionInfo$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_ExtensionInfo$vmethods {
	struct _jc_java_lang_String$object	*(*compilerName$20b6c9308360447c)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
	struct _jc_object	*(*createNodeFactory$4af76fcc0af28194)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
	struct _jc_object	*(*createTypeSystem$0b3473dcf2a9d954)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
	struct _jc_java_lang_String$object	*(*defaultFileExtension$d54a311b3a2f1a9a)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
	struct _jc_object	*(*parser$41009ef32420079c)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_io_Reader$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_object *);
	struct _jc_object	*(*passes$def8d891d63f548c)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_polyglot_frontend_Job$object *);
	struct _jc_java_util_HashMap$object	*(*sourceJobMap$320bdf7d2bd13eea)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *);
	void	(*sourceJobMap$d91400766cfa0821)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_util_HashMap$object *);
};

// Vtable
struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractExtensionInfo$vmethods	polyglot_frontend_AbstractExtensionInfo;
	_jc_polyglot_ext_jl_ExtensionInfo$vmethods	polyglot_ext_jl_ExtensionInfo;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vmethods	soot_javaToJimple_jj_ExtensionInfo;
};

// Vtype
struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs {
	struct _jc_java_util_HashMap$object	*sourceJobMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$refs {
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs	soot_javaToJimple_jj_ExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_refs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_refs	polyglot_frontend_AbstractExtensionInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_nonrefs	polyglot_frontend_AbstractExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_nonrefs	polyglot_ext_jl_ExtensionInfo;
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs	soot_javaToJimple_jj_ExtensionInfo;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_ExtensionInfo$object {
	_jc_soot_javaToJimple_jj_ExtensionInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vtype	*vtype;
	_jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_ExtensionInfo$vtype _jc_soot_javaToJimple_jj_ExtensionInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_ExtensionInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_ExtensionInfo$class_object;

#endif	/* _JC_soot_javaToJimple_jj_ExtensionInfo_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/jj/ExtensionInfo.h <==
// public class soot.javaToJimple.jj.ExtensionInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b87d6875b316a8f polyglot_ext_jl_ExtensionInfo
// @dep_class b1e2e9278240b294 polyglot_frontend_AbstractExtensionInfo
// @dep_class 155e6493c3c373f soot_javaToJimple_jj_ExtensionInfo

// header file dependencies
// @dep_header polyglot_ext_jl_ExtensionInfo

#include "polyglot/ext/jl/ExtensionInfo.h"

#ifndef _JC_soot_javaToJimple_jj_ExtensionInfo_H_
#define _JC_soot_javaToJimple_jj_ExtensionInfo_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_FileSource$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Parser$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_ErrorQueue$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs	_jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs	_jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$refs	_jc_soot_javaToJimple_jj_ExtensionInfo$refs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs	_jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ExtensionInfo$object	_jc_soot_javaToJimple_jj_ExtensionInfo$object;

typedef const struct _jc_soot_javaToJimple_jj_ExtensionInfo$vmethods	_jc_soot_javaToJimple_jj_ExtensionInfo$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtable	_jc_soot_javaToJimple_jj_ExtensionInfo$vtable;
typedef const struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtype	_jc_soot_javaToJimple_jj_ExtensionInfo$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_ExtensionInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$compilerName$20b6c9308360447c(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$createNodeFactory$4af76fcc0af28194(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$createTypeSystem$0b3473dcf2a9d954(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$defaultFileExtension$d54a311b3a2f1a9a(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$parser$41009ef32420079c(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_io_Reader$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$passes$def8d891d63f548c(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_jj_ExtensionInfo$method$sourceJobMap$320bdf7d2bd13eea(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_jj_ExtensionInfo$method$sourceJobMap$d91400766cfa0821(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_util_HashMap$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$compilerName$20b6c9308360447c;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$createNodeFactory$4af76fcc0af28194;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$createTypeSystem$0b3473dcf2a9d954;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$defaultFileExtension$d54a311b3a2f1a9a;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$parser$41009ef32420079c;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$passes$def8d891d63f548c;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$sourceJobMap$320bdf7d2bd13eea;
extern _jc_method _jc_soot_javaToJimple_jj_ExtensionInfo$method_info$sourceJobMap$d91400766cfa0821;

// Static methods
extern void _jc_soot_javaToJimple_jj_ExtensionInfo$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_ExtensionInfo$vmethods {
	struct _jc_java_lang_String$object	*(*compilerName$20b6c9308360447c)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createNodeFactory$4af76fcc0af28194)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createTypeSystem$0b3473dcf2a9d954)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*defaultFileExtension$d54a311b3a2f1a9a)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*parser$41009ef32420079c)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_io_Reader$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*passes$def8d891d63f548c)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_HashMap$object	*(*sourceJobMap$320bdf7d2bd13eea)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *) _JC_JCNI_ATTR;
	void	(*sourceJobMap$d91400766cfa0821)(_jc_env *, struct _jc_soot_javaToJimple_jj_ExtensionInfo$object *, struct _jc_java_util_HashMap$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractExtensionInfo$vmethods	polyglot_frontend_AbstractExtensionInfo;
	_jc_polyglot_ext_jl_ExtensionInfo$vmethods	polyglot_ext_jl_ExtensionInfo;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vmethods	soot_javaToJimple_jj_ExtensionInfo;
};

// Vtype
struct _jc_soot_javaToJimple_jj_ExtensionInfo$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs {
	struct _jc_java_util_HashMap$object	*sourceJobMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$refs {
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs	soot_javaToJimple_jj_ExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_refs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_refs	polyglot_frontend_AbstractExtensionInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_nonrefs	polyglot_frontend_AbstractExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_nonrefs	polyglot_ext_jl_ExtensionInfo;
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs	soot_javaToJimple_jj_ExtensionInfo;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_ExtensionInfo$object {
	_jc_soot_javaToJimple_jj_ExtensionInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vtype	*vtype;
	_jc_soot_javaToJimple_jj_ExtensionInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_ExtensionInfo$vtype _jc_soot_javaToJimple_jj_ExtensionInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_ExtensionInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_ExtensionInfo$class_object;

#endif	/* _JC_soot_javaToJimple_jj_ExtensionInfo_H_ */
